import re
import csv
import sys

safepoint_re_rule = re.compile(r'(?:Safepoint\s)"(.*)"')
total_re_rule = re.compile(r'(?:Total:\s+)(.*)')

def parse_gc(line):
    result = {
        "gc_time": 0,
    }
    
    safepoint = safepoint_re_rule.search(line)
    total = total_re_rule.search(line)
    
    total_splitted = total.group(1).split(" ")
    
    return {
        "name": safepoint.group(1),
        "total": total_splitted[0],
        "unit": total_splitted[1],
    }
    
def main(filename, output_file):
    file = open(filename, "r")
    csv_file = open(output_file, 'w')
    
    fieldnames = ["name", "total", "unit"]
    writer = csv.DictWriter(csv_file, fieldnames=fieldnames)    
    writer.writeheader()
    
    for line in file:
        gc_info = parse_gc(line)
        writer.writerow(gc_info)
        
    csv_file.close()
    file.close()
        

if __name__ == '__main__':
    # print(parse_gc('[2022-05-09T08:14:40.608+0000][0.653s] Safepoint "ICBufferFull", Time since last: 503707093 ns, Reaching safepoint: 198472 ns, At safepoint: 3707 ns, Total: 202179 ns'))
    if len(sys.argv) < 3:
        print("Run the program as follow: ")
        print("      parser.py <gc log> <output file (csv)>")
        sys.exit(1)
    main(sys.argv[1], sys.argv[2])