import pandas as pd
import glob
import csv
import matplotlib.pyplot as plt
import numpy as np

plt.style.use("ggplot")  

def plot_gc_counts(csvs):
    x_pos = [i for i, _ in enumerate(csvs.keys())]
    width = 0.35

    fig, ax = plt.subplots(figsize=(8,8))
    
    values = [value["count"] for value in csvs.values()]

    ax.bar(x_pos, values, width, color="green")
    ax.set_xlabel("Garbage Collector Algorithm", fontsize=14)
    ax.set_ylabel("", fontsize=14)
    ax.set_title("GC Count for Renaissance Benchmark", fontsize=14)

    ax.set_xticks(x_pos, list(csvs.keys()), fontsize=8)

    fig.savefig("gc_count.png")

def plot_gc_elapsed(csvs):
    x_pos = [i for i, _ in enumerate(csvs.keys())]
    width = 0.35

    fig, ax = plt.subplots(figsize=(8,8))
    
    values = [value["total"] for value in csvs.values()]

    ax.bar(x_pos, values, width, color="green")
    ax.set_xlabel("Garbage Collector Algorithm", fontsize=14)
    ax.set_ylabel("Total Elapsed Time (s)", fontsize=14)
    ax.set_title("GC Elapsed Time for Renaissance Benchmark", fontsize=14)

    ax.set_xticks(x_pos, list(csvs.keys()), fontsize=8)

    fig.savefig("gc_total.png")

def main(folder = "result"):
    files = glob.glob(f"./{folder}/*.csv")
    names = [file.replace(f"./{folder}/", "").replace(".csv", "") for file in files]
 
    csvs = {}

    for name, filename in zip(names, files):
        file = open(filename, "r")
        reader = csv.DictReader(file)
        count = 0
        total = 0
        for row in reader:
            total += int(row["total"]) / 1_000_000_000
            count += 1
        
        csvs[name] = { "count": count, "total": total }
        file.close()
        
    plot_gc_counts(csvs)
    plot_gc_elapsed(csvs)

if __name__ == "__main__":
    main()