#!/usr/bin/env bash

set -u

NODE_TYPE="${NODE_TYPE:-compute_skylake}"

public_network_id=$(openstack network show public -f value -c id)

echo "Requesting lease for:"
echo " - 1 bare metal node (type(s)=$NODE_TYPE)"
echo " - 1 Floating IPs"
echo

echo "Reserving $NODE_TYPE node"

lease_name="$RESOURCE_PREFIX_NAME-$NODE_TYPE"

echo "Reserve lease $lease_name with type $NODE_TYPE..."
blazar lease-create \
  --physical-reservation min=1,max=1,resource_properties="[\"=\", \"\$node_type\", \"$NODE_TYPE\"]" \
  --reservation resource_type=virtual:floatingip,network_id="$public_network_id",amount=1 \
  --start-date "$(date -u +'%Y-%m-%d %H:%M' -d'+1 minute')" \
  --end-date "$(date -u +'%Y-%m-%d %H:%M' -d'+1 day')" \
  "$lease_name"

echo "Waiting for lease $lease_name to start"
echo
attempts=0
wait_lease() {
  sleep 5
  attempts=$((attempts+1))
  printf "."
  [[ $attempts -gt 60 ]] && return 1
}
until [[ $(blazar lease-show "$lease_name" -f value -c status) == "ACTIVE" ]]; do wait_lease; done
echo
echo "Lease started successfully!"
echo

reservations=$(blazar lease-show "$lease_name" -f json \
  | jq -r '.reservations')
host_reservation_id=$(jq -rs 'map(select(.resource_type=="physical:host"))[].id' <<<"$reservations")
fip_reservation_id=$(jq -rs 'map(select(.resource_type=="virtual:floatingip"))[].id' <<<"$reservations")

fip=$(openstack floating ip list --tags "reservation:$fip_reservation_id" -f json)
fip_id=$(jq -r '.[0]["ID"]' <<<"$fip")
fip_addr=$(jq -r '.[0]["Floating IP Address"]' <<<"$fip")

NODE_RESERVATION_ID=$host_reservation_id
NODE_IP_ID=$fip_id
NODE_IP_ADDR=$fip_addr

export FLOATING_IP_ID=$NODE_IP_ID
export FLOATING_IP=$NODE_IP_ADDR
export RESERVATION_ID=$NODE_RESERVATION_ID

echo
echo "Stack parameters:"
echo " - floating_ip (exported as FLOATING_IP_ID and FLOATING_IP):"
echo "       - ${FLOATING_IP_ID} (addr: ${FLOATING_IP})"
echo " - reservation_id (exported as RESERVATION_ID):"
echo "       - $RESERVATION_ID"